InteractiveBrokersDataClientConfigBuilder

Struct InteractiveBrokersDataClientConfigBuilder 

pub struct InteractiveBrokersDataClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> InteractiveBrokersDataClientConfigBuilder<S>

pub fn build(self) -> InteractiveBrokersDataClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn host( self, value: String, ) -> InteractiveBrokersDataClientConfigBuilder<SetHost<S>>
where S::Host: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_HOST.to_string().

Host for IB Gateway/TWS.

pub fn maybe_host( self, value: Option<String>, ) -> InteractiveBrokersDataClientConfigBuilder<SetHost<S>>
where S::Host: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_HOST.to_string().

Host for IB Gateway/TWS.

pub fn port( self, value: u16, ) -> InteractiveBrokersDataClientConfigBuilder<SetPort<S>>
where S::Port: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_PORT.

Port for IB Gateway/TWS.

pub fn maybe_port( self, value: Option<u16>, ) -> InteractiveBrokersDataClientConfigBuilder<SetPort<S>>
where S::Port: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_PORT.

Port for IB Gateway/TWS.

pub fn client_id( self, value: i32, ) -> InteractiveBrokersDataClientConfigBuilder<SetClientId<S>>
where S::ClientId: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_CLIENT_ID.

Client ID.

pub fn maybe_client_id( self, value: Option<i32>, ) -> InteractiveBrokersDataClientConfigBuilder<SetClientId<S>>
where S::ClientId: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_CLIENT_ID.

Client ID.

pub fn use_regular_trading_hours( self, value: bool, ) -> InteractiveBrokersDataClientConfigBuilder<SetUseRegularTradingHours<S>>
where S::UseRegularTradingHours: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use regular trading hours only (RTH filtering).

pub fn maybe_use_regular_trading_hours( self, value: Option<bool>, ) -> InteractiveBrokersDataClientConfigBuilder<SetUseRegularTradingHours<S>>
where S::UseRegularTradingHours: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use regular trading hours only (RTH filtering).

pub fn market_data_type( self, value: MarketDataType, ) -> InteractiveBrokersDataClientConfigBuilder<SetMarketDataType<S>>
where S::MarketDataType: IsUnset,

Optional (Some / Option setters). Default: <MarketDataType as Default>::default().

Market data type (realtime, delayed, frozen).

pub fn maybe_market_data_type( self, value: Option<MarketDataType>, ) -> InteractiveBrokersDataClientConfigBuilder<SetMarketDataType<S>>
where S::MarketDataType: IsUnset,

Optional (Some / Option setters). Default: <MarketDataType as Default>::default().

Market data type (realtime, delayed, frozen).

pub fn ignore_quote_tick_size_updates( self, value: bool, ) -> InteractiveBrokersDataClientConfigBuilder<SetIgnoreQuoteTickSizeUpdates<S>>
where S::IgnoreQuoteTickSizeUpdates: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to ignore quote tick size updates (filters size-only updates).

pub fn maybe_ignore_quote_tick_size_updates( self, value: Option<bool>, ) -> InteractiveBrokersDataClientConfigBuilder<SetIgnoreQuoteTickSizeUpdates<S>>
where S::IgnoreQuoteTickSizeUpdates: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to ignore quote tick size updates (filters size-only updates).

pub fn connection_timeout( self, value: u64, ) -> InteractiveBrokersDataClientConfigBuilder<SetConnectionTimeout<S>>
where S::ConnectionTimeout: IsUnset,

Optional (Some / Option setters). Default: 300.

Connection timeout in seconds.

pub fn maybe_connection_timeout( self, value: Option<u64>, ) -> InteractiveBrokersDataClientConfigBuilder<SetConnectionTimeout<S>>
where S::ConnectionTimeout: IsUnset,

Optional (Some / Option setters). Default: 300.

Connection timeout in seconds.

pub fn request_timeout( self, value: u64, ) -> InteractiveBrokersDataClientConfigBuilder<SetRequestTimeout<S>>
where S::RequestTimeout: IsUnset,

Optional (Some / Option setters). Default: 60.

Request timeout in seconds. Applied to IB API requests (open orders, executions, positions, account summary, order update stream, next order id). See execution/core.rs and execution/account.rs for call sites.

pub fn maybe_request_timeout( self, value: Option<u64>, ) -> InteractiveBrokersDataClientConfigBuilder<SetRequestTimeout<S>>
where S::RequestTimeout: IsUnset,

Optional (Some / Option setters). Default: 60.

Request timeout in seconds. Applied to IB API requests (open orders, executions, positions, account summary, order update stream, next order id). See execution/core.rs and execution/account.rs for call sites.

pub fn handle_revised_bars( self, value: bool, ) -> InteractiveBrokersDataClientConfigBuilder<SetHandleRevisedBars<S>>
where S::HandleRevisedBars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to handle revised bars.

pub fn maybe_handle_revised_bars( self, value: Option<bool>, ) -> InteractiveBrokersDataClientConfigBuilder<SetHandleRevisedBars<S>>
where S::HandleRevisedBars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to handle revised bars.

pub fn batch_quotes( self, value: bool, ) -> InteractiveBrokersDataClientConfigBuilder<SetBatchQuotes<S>>
where S::BatchQuotes: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use batch quotes (reqMktData) by default instead of tick-by-tick.

pub fn maybe_batch_quotes( self, value: Option<bool>, ) -> InteractiveBrokersDataClientConfigBuilder<SetBatchQuotes<S>>
where S::BatchQuotes: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use batch quotes (reqMktData) by default instead of tick-by-tick.