InteractiveBrokersInstrumentProviderConfigBuilder

Struct InteractiveBrokersInstrumentProviderConfigBuilder 

pub struct InteractiveBrokersInstrumentProviderConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> InteractiveBrokersInstrumentProviderConfigBuilder<S>

pub fn build(self) -> InteractiveBrokersInstrumentProviderConfig
where S: IsComplete,

Finish building and return the requested object

pub fn symbology_method( self, value: SymbologyMethod, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetSymbologyMethod<S>>
where S::SymbologyMethod: IsUnset,

Optional (Some / Option setters). Default: <SymbologyMethod as Default>::default().

Symbology method to use for instrument ID conversion.

pub fn maybe_symbology_method( self, value: Option<SymbologyMethod>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetSymbologyMethod<S>>
where S::SymbologyMethod: IsUnset,

Optional (Some / Option setters). Default: <SymbologyMethod as Default>::default().

Symbology method to use for instrument ID conversion.

pub fn load_ids( self, value: HashSet<InstrumentId>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetLoadIds<S>>
where S::LoadIds: IsUnset,

Optional (Some / Option setters). Default: <HashSet<InstrumentId> as Default>::default().

Instrument IDs to load on startup.

pub fn maybe_load_ids( self, value: Option<HashSet<InstrumentId>>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetLoadIds<S>>
where S::LoadIds: IsUnset,

Optional (Some / Option setters). Default: <HashSet<InstrumentId> as Default>::default().

Instrument IDs to load on startup.

pub fn load_contracts( self, value: Vec<Value>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetLoadContracts<S>>
where S::LoadContracts: IsUnset,

Optional (Some / Option setters). Default: <Vec<serde_json::Value> as Default>::default().

IB contracts to load on startup.

pub fn maybe_load_contracts( self, value: Option<Vec<Value>>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetLoadContracts<S>>
where S::LoadContracts: IsUnset,

Optional (Some / Option setters). Default: <Vec<serde_json::Value> as Default>::default().

IB contracts to load on startup.

pub fn min_expiry_days( self, value: u32, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetMinExpiryDays<S>>
where S::MinExpiryDays: IsUnset,

Optional (Some / Option setters). Minimum expiry days for options and futures chains.

pub fn maybe_min_expiry_days( self, value: Option<u32>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetMinExpiryDays<S>>
where S::MinExpiryDays: IsUnset,

Optional (Some / Option setters). Minimum expiry days for options and futures chains.

pub fn max_expiry_days( self, value: u32, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetMaxExpiryDays<S>>
where S::MaxExpiryDays: IsUnset,

Optional (Some / Option setters). Maximum expiry days for options and futures chains.

pub fn maybe_max_expiry_days( self, value: Option<u32>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetMaxExpiryDays<S>>
where S::MaxExpiryDays: IsUnset,

Optional (Some / Option setters). Maximum expiry days for options and futures chains.

pub fn build_options_chain( self, value: bool, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetBuildOptionsChain<S>>
where S::BuildOptionsChain: IsUnset,

Optional (Some / Option setters). Whether to build full options chain.

pub fn maybe_build_options_chain( self, value: Option<bool>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetBuildOptionsChain<S>>
where S::BuildOptionsChain: IsUnset,

Optional (Some / Option setters). Whether to build full options chain.

pub fn build_futures_chain( self, value: bool, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetBuildFuturesChain<S>>
where S::BuildFuturesChain: IsUnset,

Optional (Some / Option setters). Whether to build full futures chain.

pub fn maybe_build_futures_chain( self, value: Option<bool>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetBuildFuturesChain<S>>
where S::BuildFuturesChain: IsUnset,

Optional (Some / Option setters). Whether to build full futures chain.

pub fn cache_validity_days( self, value: u32, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetCacheValidityDays<S>>
where S::CacheValidityDays: IsUnset,

Optional (Some / Option setters). Cache validity in days (None means no caching).

pub fn maybe_cache_validity_days( self, value: Option<u32>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetCacheValidityDays<S>>
where S::CacheValidityDays: IsUnset,

Optional (Some / Option setters). Cache validity in days (None means no caching).

pub fn convert_exchange_to_mic_venue( self, value: bool, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetConvertExchangeToMicVenue<S>>
where S::ConvertExchangeToMicVenue: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to convert IB exchanges to MIC venues.

pub fn maybe_convert_exchange_to_mic_venue( self, value: Option<bool>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetConvertExchangeToMicVenue<S>>
where S::ConvertExchangeToMicVenue: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to convert IB exchanges to MIC venues.

pub fn symbol_to_mic_venue( self, value: HashMap<String, String>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetSymbolToMicVenue<S>>
where S::SymbolToMicVenue: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Symbol to MIC venue mapping override.

pub fn maybe_symbol_to_mic_venue( self, value: Option<HashMap<String, String>>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetSymbolToMicVenue<S>>
where S::SymbolToMicVenue: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

Symbol to MIC venue mapping override.

pub fn filter_sec_types( self, value: HashSet<String>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetFilterSecTypes<S>>
where S::FilterSecTypes: IsUnset,

Optional (Some / Option setters). Default: <HashSet<String> as Default>::default().

Security types to filter out.

pub fn maybe_filter_sec_types( self, value: Option<HashSet<String>>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetFilterSecTypes<S>>
where S::FilterSecTypes: IsUnset,

Optional (Some / Option setters). Default: <HashSet<String> as Default>::default().

Security types to filter out.

pub fn cache_path( self, value: String, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetCachePath<S>>
where S::CachePath: IsUnset,

Optional (Some / Option setters). Path to cache file for persistent instrument caching (equivalent to pickle_path in Python). If provided, instruments will be cached to disk and loaded from cache if still valid.

pub fn maybe_cache_path( self, value: Option<String>, ) -> InteractiveBrokersInstrumentProviderConfigBuilder<SetCachePath<S>>
where S::CachePath: IsUnset,

Optional (Some / Option setters). Path to cache file for persistent instrument caching (equivalent to pickle_path in Python). If provided, instruments will be cached to disk and loaded from cache if still valid.